"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isNodejs = exports.currentDatetime = exports.currentTime = exports.currentDate = exports.isArrayBuffer = exports.str2arrayBuffer = exports.sleep = exports.tryToParseObject = exports.isObject = exports.getQuery = void 0;
/**
 * Get query parameters from the specified request url.
 * @param {string} reqUrl
 */
function getQuery(reqUrl) {
    return /\?/.test(reqUrl)
        ? reqUrl
            .replace(/.*?\?/g, '') // no protocol, domain and path
            .replace(/#.*$/g, '') // no hash tag
            .split('&')
            .reduce(function (res, item) {
            var _a = item.split('='), k = _a[0], v = _a[1];
            res[k] = (v || '').trim();
            return res;
        }, {})
        : {};
}
exports.getQuery = getQuery;
/**
 * Check whether or not this specified obj is an object.
 * @param {any} obj
 */
function isObject(obj) {
    return Object.prototype.toString.call(obj) === '[object Object]';
}
exports.isObject = isObject;
;
/**
 * Try to convert an object like string to an object.
 * @param {any} body
 */
function tryToParseObject(body) {
    if (typeof body === 'string' && body[0] === '{' && body[body.length - 1] === '}') {
        try {
            return JSON.parse(body);
        }
        catch (e) {
            return body;
        }
    }
    else {
        return body;
    }
}
exports.tryToParseObject = tryToParseObject;
/**
 * Sleep the specified number of milliseconds.
 * @param {number} ms
 */
function sleep(ms) {
    return new Promise(function (resolve) { return setTimeout(resolve, ms); });
}
exports.sleep = sleep;
/**
 * Convert string to arraybuffer.
 * @param {string} str
 */
function str2arrayBuffer(str) {
    if (typeof TextEncoder === 'function') {
        return new TextEncoder().encode(str);
    }
    var buf = new ArrayBuffer(str.length * 2); // 2 bytes for each char
    var bufView = new Uint16Array(buf);
    for (var i = 0, strLen = str.length; i < strLen; i++) {
        bufView[i] = str.charCodeAt(i);
    }
    return buf;
}
exports.str2arrayBuffer = str2arrayBuffer;
/**
 * Whether or not the specified data is arraybuffer.
 * @param {string} str
 */
function isArrayBuffer(data) {
    if (typeof ArrayBuffer === 'function' && data instanceof ArrayBuffer) {
        return true;
    }
    if (typeof Int32Array === 'function' && (data instanceof Int32Array)) {
        return true;
    }
    if (typeof Int16Array === 'function' && (data instanceof Int16Array)) {
        return true;
    }
    if (typeof Int8Array === 'function' && (data instanceof Int8Array)) {
        return true;
    }
    return false;
}
exports.isArrayBuffer = isArrayBuffer;
/**
 * Get current date.
 */
function currentDate() {
    var now = new Date();
    var year = now.getFullYear();
    var month = now.getMonth() + 1;
    var date = now.getDate();
    var two = function (num) { return num < 10 ? "0" + num : "" + num; };
    return two(year) + "-" + two(month) + "-" + two(date);
}
exports.currentDate = currentDate;
/**
 * Get current time.
 */
function currentTime() {
    var now = new Date();
    var hour = now.getHours();
    var minute = now.getMinutes();
    var second = now.getSeconds();
    var two = function (num) { return num < 10 ? "0" + num : "" + num; };
    return two(hour) + ":" + two(minute) + ":" + two(second);
}
exports.currentTime = currentTime;
/**
 * Get current datetime.
 */
function currentDatetime() {
    var now = new Date();
    var year = now.getFullYear();
    var month = now.getMonth() + 1;
    var date = now.getDate();
    var hour = now.getHours();
    var minute = now.getMinutes();
    var second = now.getSeconds();
    var two = function (num) { return num < 10 ? "0" + num : "" + num; };
    return two(year) + "-" + two(month) + "-" + two(date) + " " + two(hour) + ":" + two(minute) + ":" + two(second);
}
exports.currentDatetime = currentDatetime;
/**
 * Check current envrioment: nodejs or not.
 * Note: arrow function is required.
 */
function isNodejs() {
    return (typeof process !== 'undefined')
        && (Object.prototype.toString.call(process) === '[object process]')
        && (!!(process.versions && process.versions.node));
}
exports.isNodejs = isNodejs;
;
//# sourceMappingURL=utils.js.map