"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("../common/utils");
var config_1 = require("../config");
var fallback_1 = __importDefault(require("./fallback"));
function fakeFetch() {
    var args = __spreadArray([], arguments, true);
    var url;
    var params;
    // https://developer.mozilla.org/en-US/docs/Web/API/Request
    // Note: the first argument of fetch maybe a Request object.
    if (typeof args[0] === 'object') {
        url = args[0].url;
        params = args[0];
    }
    else {
        url = args[0];
        params = args[1] || {};
    }
    return (0, fallback_1.default)(url, params.method, params.headers, params.body)
        .then(function (res) {
        return getResponse(url, res.body, res.response);
    });
}
exports.default = fakeFetch;
function getResponse(url, responseBody, res) {
    var data = responseBody;
    var status = res.statusCode || 200;
    var statusText = config_1.HTTPStatusCodes[status] || '';
    var headers = typeof Headers === 'function'
        ? new Headers(__assign(__assign({}, res.headers), { 'x-powered-by': 'http-request-mock' }))
        : __assign(__assign({}, res.headers), { 'x-powered-by': 'http-request-mock' });
    var body = typeof Blob === 'function'
        ? new Blob([typeof data === 'string' ? data : JSON.stringify(data)])
        : data;
    if (typeof Response === 'function') {
        var response_1 = new Response(body, { status: status, statusText: statusText, headers: headers });
        Object.defineProperty(response_1, 'url', { value: url });
        return response_1;
    }
    var response = {
        body: body,
        bodyUsed: false,
        headers: headers,
        ok: true,
        redirected: false,
        status: status,
        statusText: statusText,
        url: url,
        type: 'basic',
        // response data depends on prepared data
        json: function () { return Promise.resolve(data); },
        arrayBuffer: function () {
            if ((0, utils_1.isArrayBuffer)(data)) {
                return Promise.resolve(data);
            }
            return Promise.resolve((0, utils_1.str2arrayBuffer)(typeof data === 'string' ? data : JSON.stringify(data)));
        },
        blob: function () { return Promise.resolve(body); },
        formData: function () { return Promise.resolve(data); },
        text: function () { return Promise.resolve(typeof data === 'string' ? data : JSON.stringify(data)); },
        // other methods that may be used
        clone: function () { return response; },
        error: function () { return response; },
        redirect: function () { return response; },
    };
    return response;
}
//# sourceMappingURL=fetch.js.map