"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("../common/utils");
var BaseInterceptor = /** @class */ (function () {
    function BaseInterceptor(mocker) {
        this.mocker = mocker;
        this.global = BaseInterceptor.getGlobal();
    }
    /**
     * Setup request mocker.
     * @param {Mocker} mocker
     */
    BaseInterceptor.setup = function (mocker) {
        return new this(mocker);
    };
    /**
     * return global variable
     */
    BaseInterceptor.getGlobal = function () {
        if (typeof window !== 'undefined') {
            return window;
        }
        else if (typeof global !== 'undefined') {
            return global;
        }
        throw new Error('Detect global variable error');
    };
    /**
     * Check whether the specified request url matchs a defined mock item.
     * If a match is found, return mock meta information, otherwise a null is returned.
     * @param {string} reqUrl
     * @param {string} reqMethod
     */
    BaseInterceptor.prototype.matchMockRequest = function (reqUrl, reqMethod) {
        var mockItem = this.mocker.matchMockItem(reqUrl, reqMethod);
        if (mockItem && mockItem.times !== undefined) {
            mockItem.times -= 1;
        }
        return mockItem;
    };
    BaseInterceptor.prototype.getRequestInfo = function (mixedRequestInfo) {
        var info = {
            url: mixedRequestInfo.url,
            method: mixedRequestInfo.method || 'GET',
            query: (0, utils_1.getQuery)(mixedRequestInfo.url),
        };
        if (mixedRequestInfo.headers || mixedRequestInfo.header) {
            info.headers = mixedRequestInfo.headers || mixedRequestInfo.header;
        }
        if (mixedRequestInfo.body !== undefined) {
            info.body = (0, utils_1.tryToParseObject)(mixedRequestInfo.body);
        }
        return info;
    };
    return BaseInterceptor;
}());
exports.default = BaseInterceptor;
//# sourceMappingURL=base.js.map